==> msmtp-scripts-1.2.4.tar.gz: msmtp-scripts-1.2.4/README.md <==
msmtp-scripts
-------------


[![Travis CI results](https://travis-ci.org/cshoredaniel/msmtp-scripts.svg?branch=stable-1.2)](https://travis-ci.org/cshoredaniel/msmtp-scripts?branch=stable-1.2)
[![Coverage Status](https://coveralls.io/repos/github/cshoredaniel/msmtp-scripts/badge.svg?branch=stable-1.2)](https://coveralls.io/github/cshoredaniel/msmtp-scripts?branch=stable-1.2)
[![Copr build status](https://copr.fedorainfracloud.org/coprs/cshoredaniel/msmtp-scripts/package/msmtp-scripts/status_image/last_build.png)](https://copr.fedorainfracloud.org/coprs/cshoredaniel/msmtp-scripts/package/msmtp-scripts/)

[PPA Badges not yet supported by shields.io](https://github.com/badges/shields/issues/560)

## Installation Instructions

### Ubuntu

```
sudo add-apt-repository ppa:cshoredaniel/msmtp-scripts-current-daily
sudo apt-get update
```

```sudo apt install msmtp-scripts-mta```

optionally:

```sudo apt install ms-mta-smtpd-systemd```

or:

```sudo apt install ms-mta-smtpd-xinetd```

### Debian

Add the following to ```/etc/apt/sources.list.d/msmtp-scripts.list```

```
deb http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-current-daily/ubuntu xenial main 
deb-src http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-current-daily/ubuntu xenial main 
```
or for stable series builds, add
```
deb http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-stable/ubuntu xenial main 
deb-src http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-stable/ubuntu xenial main 
```

and place the following in cshoredaniel.asc, and do ```sudo apt key add cshoredanie.asc```

```
-----BEGIN PGP PUBLIC KEY BLOCK-----

xsFNBFcE3jIBEADIDhbmR0f4TIdR24JAat1psD/gV89Ul7wOZ8joNTa+ZTrVaGKs
t0Dws6pg2UPW2SxF9G5Jgnwe+dyhL1WEjXcutfO7sKzpu4A7fk5M2DuCMHTN/Gxw
XToHBuzuUrnmY3UNXVg2rE/uaDHS7fjtSFYkZbmloFIYy7VQyAdadTwflrz6lJW4
K8U7UQymt/vrTs2gLDgtpyodqPsnnTCCJgkK4N+g7LCZoDFGv/izHTNPCy99ndFS
53En0H0wb/mhQr3I38RbwkE9iFJkxk4mVSSCLM9HN5HevcmJd7G/uf5tDrk7MGrf
gfjPxGHvKInADtRqoC6fuMpAKJMEVq+vMHKznTTZ/PsUjR8P2PqABpjP6BFfsMee
rMDXNpG8i7QX0H16BDGTJJgqCdqzDsCXOw/r++Jo1ht/gwdLA2wQAEGbptHYGzN2
jpBNCcDjRf0vQCsrZTHADiaaCp6OCBf7Z0kg4PiFuAFOBeGAkWtYumv0SQbBr5O+
4TFwgxHLwEhLouO5bcJ1cppf7PBS2+/k7/2Wnzua30Su6CAsDYCzwHLLD1KYZQ6Y
ri8SCR5pNmdWlFx6OabPsAeJCIMsrsnv/pf3M0lEpeLSkH8XggJlXIoqswiBSDX6
Z9LEiAETsEOJGnyBlZBFfSGUUXal4fF+5ivhqAuGq3DGOWGzovbvqbidCwARAQAB
zSlMYXVuY2hwYWQgUFBBIGZvciBEYW5pZWwgQ3VycmFuLURpY2tpbnNvbsLBeAQT
AQIAIgUCVwTeMgIbAwYLCQgHAwIGFQgCCQoLBBYCAwECHgECF4AACgkQLPyrdSTq
U2HBAw/+Nc2ypFnVjUcOKiVzrOJo9lqmFTFMH2GRALP5+4/8+tZtHxSlaEhJsWre
iCPPWoen3ulhS3mgDU6CZVgv0UUbV+EO8HXJz29QyZ75CqxtLwat7k1pr+U/AfhB
imwkkhv3/qp8W9rP54l/7+kXURKShG0AQlxqLfURNlJNTZNfUUDOIqULK4HSL9TX
HyS+G5LGQU1mZHRfyUuGv1qCNCjWS8ZO924p9MMfwWNx77Cu8wGMWrIx8GJbh3ES
ZR0/Htpd4Cxnr//p1N551OWQh/20Y96rXiwcNR372baERSCHE9vsyEaawK5m4qQo
6FlSwRRWIXgDitY4Uik2LYgS/a3PR0OTR2l/A9O8P+FdS6uY4/gZ+xjZOcainHCl
3gnQx6ABY38DA9bltzc2p4k+/m2/sbHQqB9l9V06GKjZXWKLcaIY7nvhdITjCftR
5uVe8x2DY979dNT2UbxeRxPUys7oG2Wvw+RjKpy+aqra7JJdfuzDc78Gnw7VTf+A
To+udTIbKtQbrOR7eNACOgyAcOeeS1JcuttGsthH0QOuqAaMD6HlYekfrI+ATICh
5yOEzjOTElfOuaCSH6FKnYT8+nl7mO4SRAvy+tL7sWreotiWNRq9x7dUC+E3PNAT
gF6471JGiS3las984V8zCQlehtQXsk2ca6D8MEPNQ3os5FUv8oA=
=fGT0
-----END PGP PUBLIC KEY BLOCK-----
```

```sudo apt update```

```sudo apt install msmtp-scripts-mta```

optionally:

```sudo apt install ms-mta-smtpd-systemd```

or:

```sudo apt install ms-mta-smtpd-xinetd```

### CentOS 7

```
yum install yum-plugin-copr
yum copr enable cshoredaniel/msmtp-scripts-ci
yum swap postfix msmtp-scripts-msmtpq-ng-mta
```
optionally:
```
yum install msmtp-scripts-ms-mta-smtpd-systemd
```
or:
```
yum install msmtp-scripts-ms-mta-smtpd-xinetd
```

**NB**: For stable series builds use ```yum copr enable cshoredaniel/msmtp-scripts```
instead of ```yum copr enable cshoredaniel/msmtp-scripts-ci```

### Fedora 30 & Rawhide

```
dnf copr enable cshoredaniel/msmtp-scripts-ci
dnf swap postfix msmtp-scripts-msmtpq-ng-mta
```
optionally:
```
dnf install msmtp-scripts-ms-mta-smtpd-systemd
```
or:
```
dnf install msmtp-scripts-ms-mta-smtpd-xinetd
```

**NB**: For stables series builds use ```dnf copr enable cshoredaniel/msmtp-scripts```
instead of ```dnf copr enable cshoredaniel/msmtp-scripts-ci```

## Post-Install

You will will need to create a configuration files for msmtp (the
SMTP client that msmtp-scripts uses).  For
msmtpq-ng-mta (fedora/enterprise linux) / 
msmtp-scripts-mta (debian/ubuntu) the default location where you
need to add the file is ```/etc/msmtprc```

See ```man 1 msmtp``` for what needs to be included in the file.

## Description

### Overview

These scripts are wrappers around the msmtp SMTP client that add additional
functionality.

The primary purpose is to allow the use of msmtp as replacement for
sendmail with including queueing, and the option to require that email
be confirmed after some delay before sending it out.

Most of the scripts are modified from the msmtpq script originally from
the msmtp project.

### Revived

I had deprecated this (see below) but for a couple of specific simple use cases
it's still useful and a user request prompted me to unarchive it.

### Use Cases

* Embedded devices where a user does not have a full blown mail server
on their local network and we don't want to lose mail due to lose of
connectivity to the internet.
  * Specifically we're here for the use case when the mail is non-
critical so if a major event (i.e. total power loss, resulting in
loss of queue in RAM) happens it's not the end of the world, but
you'd still prefer not to lose the mail to a temporary internet
issue.  In that case other solutions may be overkill or, like ssmtp,
you'll lose mail if the outgoing mail server is unreachable at the
time.
    * But: If mail loss is an issue, it would be better to have a way
to host a turnkey mail server for local and vpn mail only, on the
local network
* Devices where space is a premium but where mail service is wanted
    * But: msmtp is really bigger than is ideal for this anyway

* As a replacement for system mail queue on 'standard' distros
  * Doesn't have the problem of losing mail that embedded systems
    with queue in RAM do.
  * It is quite small and avoids having a bulky and complex mail system
    just to get system messages.
  
### Additional Notes

* Was initially created as a quick hack and although progress has
been made on adding somewhat proper CI.
	* Tests are pretty ad-hoc at the moment
* Written in POSIX shell and that is unlikely to change as the
effort required to write in something like C is in far in excess of
the need for the application.

## WARNING: Tests modify your root filesystem

* The tests are designed for throwaway containers such as Travis and
therefore feel free to modify the root filesystem.  You shouldn't
run them on a production system.

### License

    Copyright (C) 2016-2019 Daniel F. Dickinson <cshored@thecshore.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

==> msmtp-scripts-1.2.5.1.tar.gz: msmtp-scripts-1.2.5.1/README.md <==
msmtp-scripts
-------------


[![Travis CI results](https://travis-ci.org/cshoredaniel/msmtp-scripts.svg?branch=stable-1.2)](https://travis-ci.org/cshoredaniel/msmtp-scripts?branch=stable-1.2)
[![Coverage Status](https://coveralls.io/repos/github/cshoredaniel/msmtp-scripts/badge.svg?branch=stable-1.2)](https://coveralls.io/github/cshoredaniel/msmtp-scripts?branch=stable-1.2)
[![Copr build status](https://copr.fedorainfracloud.org/coprs/cshoredaniel/msmtp-scripts/package/msmtp-scripts/status_image/last_build.png)](https://copr.fedorainfracloud.org/coprs/cshoredaniel/msmtp-scripts/package/msmtp-scripts/)

[PPA Badges not yet supported by shields.io](https://github.com/badges/shields/issues/560)

## Installation Instructions

### Ubuntu

```
sudo add-apt-repository ppa:cshoredaniel/msmtp-scripts-current-daily
sudo apt-get update
```

``sudo apt install msmtp-scripts-mta``

``systemctl enable --now ms-mta-queue-runner.timer``

optionally:

``sudo apt install ms-mta-smtpd-systemd``

or:

``sudo apt install ms-mta-smtpd-xinetd``

### Debian

Add the following to ``/etc/apt/sources.list.d/msmtp-scripts.list``

```
deb http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-current-daily/ubuntu xenial main 
deb-src http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-current-daily/ubuntu xenial main 
```
or for stable series builds, add
```
deb http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-stable/ubuntu xenial main 
deb-src http://ppa.launchpad.net/cshoredaniel/msmtp-scripts-stable/ubuntu xenial main 
```

Obtain the PPA's GnuPG keys.

For current-daily: https://keyserver.ubuntu.com/pks/lookup?fingerprint=on&op=index&search=0x4E24895B5E8671D17D821DD62CFCAB7524EA5361

Or for stable: https://keyserver.ubuntu.com/pks/lookup?fingerprint=on&op=index&search=0x4E24895B5E8671D17D821DD62CFCAB7524EA5361

Assuming you have saved the key as ``msmtp-scripts.asc``, do

```
sudo apt key add msmtp-scripts.asc
```

``sudo apt update``

``sudo apt install msmtp-scripts-mta``

systemctl enable --now ms-mta-queue-runner.timer

optionally:

``sudo apt install ms-mta-smtpd-systemd``

or:

```sudo apt install ms-mta-smtpd-xinetd```

### CentOS 7

```
yum install yum-plugin-copr
yum copr enable cshoredaniel/msmtp-scripts-ci
yum swap postfix msmtp-scripts-msmtpq-ng-mta
systemctl enable --now ms-mta-queue-runner.timer
```
optionally:
```
yum install msmtp-scripts-ms-mta-smtpd-systemd
```
or:
```
yum install msmtp-scripts-ms-mta-smtpd-xinetd
```

**NB**: For stable series builds use ```yum copr enable cshoredaniel/msmtp-scripts```
instead of ```yum copr enable cshoredaniel/msmtp-scripts-ci```

### Fedora 30 & Rawhide

```
dnf copr enable cshoredaniel/msmtp-scripts-ci
dnf swap postfix msmtp-scripts-msmtpq-ng-mta
systemctl enable --now ms-mta-queue-runner.timer
```
optionally:
```
dnf install msmtp-scripts-ms-mta-smtpd-systemd
```
or:
```
dnf install msmtp-scripts-ms-mta-smtpd-xinetd
```

**NB**: For stables series builds use ```dnf copr enable cshoredaniel/msmtp-scripts```
instead of ```dnf copr enable cshoredaniel/msmtp-scripts-ci```

## Post-Install

You will will need to create a configuration files for msmtp (the
SMTP client that msmtp-scripts uses).  For
msmtpq-ng-mta (fedora/enterprise linux) / 
msmtp-scripts-mta (debian/ubuntu) the default location where you
need to add the file is ``/etc/msmtprc``

See ``man 1 msmtp`` for what needs to be included in the file.

## Description

### Overview

These scripts are wrappers around the msmtp SMTP client that add additional
functionality.

The primary purpose is to allow the use of msmtp as replacement for
sendmail with including queueing, and the option to require that email
be confirmed after some delay before sending it out.

Most of the scripts are modified from the msmtpq script originally from
the msmtp project.

### Use Cases

* Embedded devices where a user does not have a full blown mail server
on their local network and we don't want to lose mail due to lose of
connectivity to the internet.
  * Specifically we're here for the use case when the mail is non-
critical so if a major event (i.e. total power loss, resulting in
loss of queue in RAM) happens it's not the end of the world, but
you'd still prefer not to lose the mail to a temporary internet
issue.  In that case other solutions may be overkill or, like ssmtp,
you'll lose mail if the outgoing mail server is unreachable at the
time.
    * But: If mail loss is an issue, it would be better to have a way
to host a turnkey mail server for local and vpn mail only, on the
local network
* Devices where space is at a premium but where mail service is wanted

* As a replacement for system mail queue on 'standard' distros
  * Doesn't have the problem of losing mail that embedded systems
    with queue in RAM do.
  * It is quite small and avoids having a bulky and complex mail system
    just to get system messages.
  * The downside is that you have to watch out for permissions issues
    (e.g. SELinux issues) since the queuing mail happens as the user
    or process which is generating the mail.
  
### Additional Notes

* Was initially created as a quick hack and although progress has
been made on adding somewhat proper CI.
	* Tests are pretty ad-hoc at the moment
* Written in POSIX shell and that is unlikely to change as the
effort required to write in something like C is in far in excess of
the need for the application.

## WARNING: Tests modify your root filesystem

* The tests are designed for throwaway containers such as Travis and
therefore feel free to modify the root filesystem.  You shouldn't
run them on a production system.

### License

    Copyright (C) 2016-2019 Daniel F. Dickinson <cshored@thecshore.com>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
